@@ -2,7 +2,7 @@
 #include "fmt_ptime.h"
 #include "fmt.h"
 
-unsigned int fmt_ptime(char *s, struct taia *ta) {
+unsigned int fmt_ptime2(char *s, struct taia *ta, char sep) {
   struct tm *t;
   unsigned long u;
 
@@ -12,13 +12,21 @@ unsigned int fmt_ptime(char *s, struct taia *ta) {
   fmt_ulong(s, 1900 +t->tm_year);
   s[4] ='-'; fmt_uint0(&s[5], t->tm_mon +1, 2);
   s[7] ='-'; fmt_uint0(&s[8], t->tm_mday, 2);
-  s[10] ='_'; fmt_uint0(&s[11], t->tm_hour, 2);
+  s[10] =sep; fmt_uint0(&s[11], t->tm_hour, 2);
   s[13] =':'; fmt_uint0(&s[14], t->tm_min, 2);
   s[16] =':'; fmt_uint0(&s[17], t->tm_sec, 2);
   s[19] ='.'; fmt_uint0(&s[20], ta->nano, 9);
   return(25);
 }
 
+unsigned int fmt_ptime(char *s, struct taia *ta) {
+  return(fmt_ptime2(s, ta, '_'));
+}
+
+unsigned int fmt_ptime_iso8601(char *s, struct taia *ta) {
+  return(fmt_ptime2(s, ta, 'T'));
+}
+
 unsigned int fmt_taia(char *s, struct taia *t) {
   static char hex[16] ="0123456789abcdef";
   static char pack[TAIA_PACK];
